# -*- coding: utf-8 -*-
"""
Created on Thu Nov  7 15:31:13 2024

@author: mstep
"""

#!/usr/bin/env python
# coding: utf-8

# In[2]:

import tkinter as tk
from tkinter import ttk
import math

class SierpinskiPentagonApp:
    def __init__(self):
        self.window = tk.Tk()
        self.window.title('sierpinski_pentagon')
        self.window.protocol('WM_DELETE_WINDOW', self.kill_callback)
        self.window.geometry('500x500')

        # Left frame.
        frame = tk.Frame(self.window)
        frame.pack(side=tk.TOP, anchor=tk.W, padx=3, pady=3)

        label = tk.Label(frame, text='Depth:')
        label.pack(side=tk.LEFT, anchor=tk.W)

        self.depth_var = tk.IntVar(value=0)
        depth_spinbox = ttk.Spinbox(frame, from_=0, to=6, width=4,
            textvariable=self.depth_var, command=self.draw)
        depth_spinbox.pack(side=tk.LEFT)

        # Canvas.
        self.canvas = tk.Canvas(self.window, bg='white', borderwidth=2,
                                relief=tk.SUNKEN)
        self.canvas.pack(side=tk.TOP, fill=tk.BOTH,
                         expand=True, padx=3, pady=3)

        # Draw the initial Sierpinski pentagon.
        self.window.after(100, self.draw)

        depth_spinbox.focus_force()
        self.window.mainloop()

    def kill_callback(self):
        # Destroy the tkinter window.
        self.window.destroy()

    def draw(self):
        self.canvas.delete(tk.ALL)
        depth = self.depth_var.get()
        center = (
            self.canvas.winfo_width() / 2,
            self.canvas.winfo_height() / 2
        )
        radius = min(center[0],  center[1]) - 5
        self.draw_pentagon(depth, center, radius)

    def draw_pentagon(self, depth, center, radius):
        '''Draw a sierpinski pentagon.'''
        # Scale factor for moving to smaller pentagons.
        size_scale = 1 / (2 * (1 + math.cos(math.pi / 180 * 72)))

        # If we are done recursing, draw the pentagon.
        if depth <= 0:
            # Find the pentagon's corners.
            points = self.get_pentagon_points(center, radius)
            self.canvas.create_polygon(points, fill='blue')
        else:
            # Find the smaller pentagons' centers.
            d = radius - radius * size_scale
            centers = self.get_pentagon_points(center, d)

            # Recursively draw the smaller pentagons.
            for point in centers:
                self.draw_pentagon(depth - 1, point, radius * size_scale)

    def get_pentagon_points(self, center, radius):
        ''' Find the pentagon's corners.'''
        points = []
        theta = -math.pi / 2
        dtheta = 2 * math.pi / 5
        for i in range(5):
            points.append(
                (
                    center[0] + radius * math.cos(theta),
                    center[1] + radius * math.sin(theta)
                )
            )
            theta += dtheta
        return points

# In[3]:

SierpinskiPentagonApp()
print('Done')


# In[ ]:
